==> standard_banner-1.0.3.tar.gz: standard_banner/README.md <==
# Standard Banner

Standard Banner is a module that introduces the ability to quickly
 add and modify banner blocks, enabling non-technical users to update 
 the layout and add images to the banner block. The layout shifts
  depending on the number of images added.

 * For a full description of the module, visit the
   [project page](https://www.drupal.org/project/standard_banner).

 * Submit bug reports and feature suggestions, or track changes in the
   [issue queue](https://www.drupal.org/project/issues/search/standard_banner).

## Contents of this file

  - Requirements
  - Installation
  - Maintainers

## Requirements

Block and Media modules are required to run this module.

## Installation

 Install as you would normally install a contributed Drupal module.
   See: https://www.drupal.org/node/895232 for further information.

## Configuration

 * Enable the module at Administration > Extend.
 * The new option, "Add Standard Banner block" will appear in 
   the menu under Structure > Blocks.
 * After creating a Standard Banner block, you can edit or delete 
   it in the custom block library as with any other custom block.
    NOTE: The layout is unable to be changed at this stage.
     If you need a different layout, create a new Standard 
     Banner block with the appropriate layout.
 * Similarly, you can manage the visibility and region of 
 the Standard Banner block in the regular Blocks menu.

## Maintainers

Current maintainers:
 * Ryan McConnell - [RyanCMcConnell](https://www.drupal.org/u/RyanCMcConnell)

This project has been sponsored by:
 * Klein Tools

==> standard_banner-1.0.5.tar.gz: standard_banner/README.md <==
# Standard Banner

Standard Banner is a module that introduces the ability to quickly
 add and modify banner blocks, enabling non-technical users to update 
 the layout and add images to the banner block. The layout shifts
  depending on the number of images added.

 * For a full description of the module, visit the
   [project page](https://www.drupal.org/project/standard_banner).

 * Submit bug reports and feature suggestions, or track changes in the
   [issue queue](https://www.drupal.org/project/issues/search/standard_banner).

## Contents of this file

  - Requirements
  - Installation
  - Maintainers

## Requirements

Block and Media modules are required to run this module.

## Installation

 Install as you would normally install a contributed Drupal module.
   See: https://www.drupal.org/node/895232 for further information.

## Configuration

 * Enable the module at Administration > Extend. 
 * The new option, "Add Standard Banner block" will appear in the menu under Structure > Blocks.
 * After creating a Standard Banner block, you can edit or delete it in the custom block library as with any other custom block. NOTE: The layout is unable to be changed at this stage. If you need a different layout, create a new Standard Banner block with the appropriate layout.
 * Similarly, you can manage the visibility and region of the Standard Banner block in the regular Blocks menu.


## Maintainers

Current maintainers:
 * Ryan McConnell - [RyanCMcConnell](https://www.drupal.org/u/RyanCMcConnell)

This project has been sponsored by:
 * Klein Tools
